@@ -3,7 +3,6 @@ package fs
 import (
 	"bufio"
 	"bytes"
-	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -194,9 +193,9 @@ func (st *statementTokenizer) statements() ([]*Statement, error) {
 		st.processLine(line, err == io.EOF)
 	}
 	if st.inQuote != 0 {
-		err = fmt.Errorf("File %s has unterminated quote %c", st.filePath, st.inQuote)
+		err = SQLContentsError(fmt.Sprintf("File %s has unterminated quote %c", st.filePath, st.inQuote))
 	} else if st.inCComment {
-		err = fmt.Errorf("File %s has unterminated C-style comment", st.filePath)
+		err = SQLContentsError(fmt.Sprintf("File %s has unterminated C-style comment", st.filePath))
 	} else {
 		err = nil
 	}
@@ -275,13 +274,13 @@ func (st *statementTokenizer) processLine(line string, eof bool) {
 		// (and requires special care to handle transititions like e.g. going from
 		// a single semicolon delimiter to double-semicolon delimiter!)
 		if bufLen := ls.buf.Len(); (bufLen == 4 || bufLen == 10) && unicode.IsSpace(c) { // potentially USE or DELIMITER followed by whitespace
-			var slurpLineAsCommand bool
-			if lowerBufStr := strings.ToLower(ls.buf.String()); strings.HasPrefix(lowerBufStr, "use") && !strings.Contains(ls.line[ls.pos:], st.delimiter) {
-				slurpLineAsCommand = true
-			} else if strings.HasPrefix(lowerBufStr, "delimiter") {
-				slurpLineAsCommand = true
-			}
-			if slurpLineAsCommand {
+			// Treat this line as a command if the current char is a space and the
+			// preceeding line content is "use" or "delimiter", case-insensitive. For
+			// "use", we only do this if there's no delimiter later on the line though,
+			// since it can optionally be present (potentially followed by other
+			// separate statements, which we should not slurp up!)
+			bufStr := strings.ToLower(ls.buf.String()[0 : bufLen-1])
+			if bufStr == "delimiter" || (bufStr == "use" && !ls.containsDelimiter()) {
 				ls.buf.WriteString(ls.line[ls.pos:])
 				ls.stmt.delimiter = "\000" // prevent SplitTextBody from stripping previous delimiter from command arg
 				ls.doneStatement(0)
@@ -356,6 +355,12 @@ func (ls *lineState) peekRunes(n int) string {
 	return ls.line[ls.pos:pos]
 }
 
+// containsDelimiter returns true if the line contains the current delimiter
+// string beyond the current position.
+func (ls *lineState) containsDelimiter() bool {
+	return strings.Contains(ls.line[ls.pos:], ls.delimiter)
+}
+
 // beginStatement records the starting position of the next (not yet fully
 // tokenized) statement.
 func (ls *lineState) beginStatement() {
@@ -399,7 +404,7 @@ func (ls *lineState) parseStatement() {
 		if err := nameParser.ParseString(txt, sqlStmt); err != nil || sqlStmt.forbidden() {
 			if err == nil { // forbidden statement
 				ls.stmt.Type = StatementTypeForbidden
-				ls.stmt.Error = errors.New("Statements such as CREATE TABLE...LIKE and CREATE TABLE...SELECT are not supported")
+				ls.stmt.Error = fmt.Errorf("%s: Statements of the form CREATE TABLE...SELECT are not supported", ls.stmt.File)
 			} else if lexErr, ok := err.(*lexer.Error); ok { // lexer error, potentially bad
 				ls.stmt.Type = StatementTypeLexError
 				fileLine, fileCol := ls.stmt.LineNo+lexErr.Tok.Pos.Line-1, lexErr.Tok.Pos.Column
@@ -471,7 +476,7 @@ var (
 		`|(--([\s\p{Zs}][^\n]*)??(?:\n|$))` +
 		`|(/\*(.|\n)*?\*/)` +
 		`|([\s\p{Zs}]+)` +
-		"|(?P<Word>[0-9a-zA-Z$_]+|`(?:[^`]|``)+`)" +
+		"|(?P<Word>[0-9a-zA-Z\u0080-\uFFFF$_]+|`(?:[^`]|``)+`)" +
 		`|(?P<String>('(\\\\|\\'|''|[^'])*')|("(\\\\|\\"|""|[^"])*"))` +
 		`|(?P<Number>[-+]?\d*\.?\d+([eE][-+]?\d+)?)` +
 		`|(?P<Operator><>|!=|<=|>=|:=|[-+*/%,.()=<>@;~!^&:|])`,
@@ -495,13 +500,11 @@ type sqlStatement struct {
 // forbidden returns true if the statement can be parsed, but is of a disallowed
 // form by this package.
 func (sqlStmt *sqlStatement) forbidden() bool {
-	// Forbid CREATE TABLE...LIKE and CREATE TABLE...SELECT. Both are potentially
-	// ordering-dependent; and the latter mixes DML, which violates "workspace
-	// tables should be empty" validations.
+	// Forbid CREATE TABLE...SELECT since it also mixes DML, violating the
+	// "workspace tables must be empty" validation upon workspace cleanup
 	if sqlStmt.CreateTable != nil {
 		for _, token := range sqlStmt.CreateTable.Body.Contents {
-			token = strings.ToUpper(token)
-			if token == "LIKE" || token == "SELECT" {
+			if len(token) == 6 && strings.ToUpper(token) == "SELECT" {
 				return true
 			}
 		}
