@@ -107,7 +107,7 @@ func querySchemaTables(ctx context.Context, db *sqlx.DB, schema string, flavor F
 		}
 		// Index order is unpredictable with new MySQL 8 data dictionary, so reorder
 		// indexes based on parsing SHOW CREATE TABLE if needed
-		if flavor.HasDataDictionary() && len(t.SecondaryIndexes) > 1 {
+		if flavor.Min(FlavorMySQL80) && len(t.SecondaryIndexes) > 1 {
 			fixIndexOrder(t)
 		}
 		// Foreign keys order is unpredictable in MySQL before 5.6, so reorder
@@ -116,23 +116,24 @@ func querySchemaTables(ctx context.Context, db *sqlx.DB, schema string, flavor F
 			fixForeignKeyOrder(t)
 		}
 		// Create options order is unpredictable with the new MySQL 8 data dictionary
-		// Also need to fix superfluous column charsets and utf8mb3->utf8 change
-		if flavor.HasDataDictionary() {
+		// Also need to fix some charset/collation edge cases in SHOW CREATE TABLE
+		// behavior in MySQL 8
+		if flavor.Min(FlavorMySQL80) {
 			fixCreateOptionsOrder(t, flavor)
-			fixShowCreateCharSets(t, flavor)
+			fixShowCharSets(t)
 		}
 		// MySQL 5.7+ generated column expressions must be reparased from SHOW CREATE
 		// TABLE to properly obtain any 4-byte chars. Additionally in 8.0 the I_S
 		// representation has incorrect escaping and potentially different charset
 		// in string literal introducers.
-		if flavor.MySQLishMinVersion(5, 7) {
+		if flavor.Min(FlavorMySQL57) {
 			fixGenerationExpr(t, flavor)
 		}
 		// Percona Server column compression can only be parsed from SHOW CREATE
 		// TABLE. (Although it also has new I_S tables, their name differs pre-8.0
 		// vs post-8.0, and cols that aren't using a COMPRESSION_DICTIONARY are not
 		// even present there.)
-		if flavor.VendorMinVersion(VendorPercona, 5, 6, 33) && strings.Contains(t.CreateStatement, "COLUMN_FORMAT COMPRESSED") {
+		if flavor.Min(FlavorPercona56.Dot(33)) && strings.Contains(t.CreateStatement, "COLUMN_FORMAT COMPRESSED") {
 			fixPerconaColCompression(t)
 		}
 		// FULLTEXT indexes may have a PARSER clause, which isn't exposed in I_S
@@ -141,7 +142,7 @@ func querySchemaTables(ctx context.Context, db *sqlx.DB, schema string, flavor F
 		}
 		// Fix problems with I_S data for default expressions as well as functional
 		// indexes in MySQL 8
-		if flavor.MySQLishMinVersion(8, 0) {
+		if flavor.Min(FlavorMySQL80) {
 			fixDefaultExpression(t, flavor)
 			fixIndexExpression(t, flavor)
 		}
@@ -264,8 +265,8 @@ func queryColumnsInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 		// I_S may still contain int display widths even though SHOW CREATE TABLE
 		// omits them. Strip to avoid incorrectly flagging the table as unsupported
 		// for diffs.
-		if stripDisplayWidth && (strings.Contains(col.TypeInDB, "int(") || col.TypeInDB == "year(4)") {
-			col.TypeInDB = StripDisplayWidth(col.TypeInDB)
+		if stripDisplayWidth {
+			col.TypeInDB, _ = StripDisplayWidth(col.TypeInDB) // safe/no-op if already no int display width
 		}
 		if pos := strings.Index(col.TypeInDB, " /*!100301 COMPRESSED"); pos > -1 {
 			// MariaDB includes compression attribute in column type; remove it
@@ -278,11 +279,13 @@ func queryColumnsInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 		}
 		if !rawColumn.Default.Valid {
 			allowNullDefault := col.Nullable && !col.AutoIncrement && col.GenerationExpr == ""
-			if !flavor.AllowBlobDefaults() && (strings.HasSuffix(col.TypeInDB, "blob") || strings.HasSuffix(col.TypeInDB, "text")) {
+			// Only MariaDB 10.2+ allows blob/text default literals, including explicit
+			// DEFAULT NULL clause.
+			// Recent versions of MySQL do allow default *expressions* for these col
+			// types, but 8.0.13-8.0.22 erroneously omit them from I_S, so we need to
+			// catch this situation and parse from SHOW CREATE later.
+			if !flavor.Min(FlavorMariaDB102) && (strings.HasSuffix(col.TypeInDB, "blob") || strings.HasSuffix(col.TypeInDB, "text")) {
 				allowNullDefault = false
-				// MySQL 8.0.13-8.0.22 omits blob/text default expressions from
-				// information_schema due to a bug, so in this case flag the column to
-				// have its default parsed out from SHOW CREATE TABLE later
 				if strings.Contains(rawColumn.Extra, "DEFAULT_GENERATED") {
 					col.Default = "(!!!BLOBDEFAULT!!!)"
 				}
@@ -290,7 +293,7 @@ func queryColumnsInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 			if allowNullDefault {
 				col.Default = "NULL"
 			}
-		} else if flavor.VendorMinVersion(VendorMariaDB, 10, 2) {
+		} else if flavor.Min(FlavorMariaDB102) {
 			if !col.AutoIncrement && col.GenerationExpr == "" {
 				// MariaDB 10.2+ exposes defaults as expressions / quote-wrapped strings
 				col.Default = rawColumn.Default.String
@@ -353,13 +356,13 @@ func queryIndexesInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 		FROM     information_schema.statistics
 		WHERE    table_schema = ?`
 	exprSelect, visSelect := "NULL", "'YES'"
-	if flavor.MySQLishMinVersion(8, 0) {
+	if flavor.Min(FlavorMySQL80) {
 		// Index expressions added in 8.0.13
-		if flavor.MySQLishMinVersion(8, 0, 13) {
+		if flavor.Min(FlavorMySQL80.Dot(13)) {
 			exprSelect = "expression"
 		}
 		visSelect = "is_visible" // available in all 8.0
-	} else if flavor.VendorMinVersion(VendorMariaDB, 10, 6) {
+	} else if flavor.Min(FlavorMariaDB106) {
 		// MariaDB I_S uses the inverse: YES for ignored (invisible), NO for visible
 		visSelect = "IF(ignored = 'YES', 'NO', 'YES')"
 	}
@@ -491,7 +494,7 @@ func queryChecksInSchema(ctx context.Context, db *sqlx.DB, schema string, flavor
 	// broken double-escaping logic. Instead we parse bodies from SHOW CREATE
 	// TABLE separately in a fixup function.
 	var query string
-	if flavor.Vendor == VendorMariaDB {
+	if flavor.IsMariaDB() {
 		query = `
 			SELECT   SQL_BUFFER_RESULT
 			         constraint_name AS constraint_name, check_clause AS check_clause,
@@ -649,56 +652,34 @@ func fixCreateOptionsOrder(t *Table, flavor Flavor) {
 	}
 }
 
-var reColumnNameFromLine = regexp.MustCompile("^\\s*`((?:[^`]|``)+)`")
-
-// This function manipulates the SHOW CREATE text to normalize some weirdness
-// from MySQL 8.0:
+// fixShowCharSets parses SHOW CREATE TABLE to set ForceShowCharSet and
+// ForceShowCollation for columns when needed in MySQL 8:
+//
+// Prior to MySQL 8, the logic behind inclusion of column-level CHARACTER SET
+// and COLLATE clauses in SHOW CREATE TABLE was weird but straightforward:
+// CHARACTER SET was included whenever the col's *collation* differed from the
+// table's default; COLLATION was included whenever the col's collation differed
+// from the default collation *of the col's charset*.
+//
+// MySQL 8 includes these clauses unnecessarily in additional situations:
 // * 8.0 includes column-level character sets and collations whenever specified
 //   explicitly in the original CREATE, even when equal to the table's defaults
 // * Tables upgraded from pre-8.0 may omit COLLATE if it's the default for the
-//   charset, while tables created in 8.0 will include it
-// * 8.0.24+ uses "utf8mb3" for table-level default in place of "utf8", but
-//   doesn't do this for columns
-func fixShowCreateCharSets(t *Table, flavor Flavor) {
-	// Find columns with unnecessary charset+collation clause, and replace with
-	// either blank string (if collation is default for the charset) or just the
-	// collation; this matches SHOW CREATE behavior for columns that didn't have
-	// the superfluous clauses
-	find := fmt.Sprintf(" CHARACTER SET %s COLLATE %s", t.CharSet, t.Collation)
-	var replace string
-	if !t.CollationIsDefault {
-		replace = fmt.Sprintf(" COLLATE %s", t.Collation)
-	}
-	t.CreateStatement = strings.ReplaceAll(t.CreateStatement, find, replace)
-
-	// Fix columns created pre-8.0-upgrade which have CHARACTER SET but no COLLATE
-	// clause: if collation matches table default, remove CHARACTER SET entirely,
-	// otherwise add the missing COLLATE
-	var colsByName map[string]*Column // populated lazily only if needed
-	for _, line := range strings.Split(t.CreateStatement, "\n") {
-		if !strings.Contains(line, "CHARACTER SET") || strings.Contains(line, "COLLATE") {
-			continue
+//   charset, while tables created in 8.0 will generally include it whenever a
+//   CHARACTER SET is shown in a column definition
+func fixShowCharSets(t *Table) {
+	lines := strings.Split(t.CreateStatement, "\n")
+	for n, col := range t.Columns {
+		if col.CharSet == "" || col.Collation == "" {
+			continue // non-character-based column type, nothing to do
 		}
-		if colsByName == nil {
-			colsByName = t.ColumnsByName()
+		line := lines[n+1] // columns start on second line of CREATE TABLE
+		if col.Collation == t.Collation && strings.Contains(line, "CHARACTER SET "+col.CharSet) {
+			col.ForceShowCharSet = true
 		}
-		// Intentionally no nil guards here -- regex should always match and col should always be found -- if not, panic is appropriate!
-		matches := reColumnNameFromLine.FindStringSubmatch(line)
-		col := colsByName[matches[1]]
-		charSetClause, collateClause := " CHARACTER SET "+col.CharSet, " COLLATE "+col.Collation
-		var fixedLine string
-		if col.Collation == t.Collation {
-			fixedLine = strings.Replace(line, charSetClause, "", 1)
-		} else {
-			fixedLine = strings.Replace(line, charSetClause, charSetClause+collateClause, 1)
+		if col.CollationIsDefault && strings.Contains(line, "COLLATE "+col.Collation) {
+			col.ForceShowCollation = true
 		}
-		t.CreateStatement = strings.Replace(t.CreateStatement, line, fixedLine, 1)
-	}
-
-	// If table-level default is utf8 according to I_S, fix the SHOW CREATE in
-	// 8.0.24+ to match
-	if t.CharSet == "utf8" && flavor.MySQLishMinVersion(8, 0, 24) {
-		t.CreateStatement = strings.Replace(t.CreateStatement, "DEFAULT CHARSET=utf8mb3", "DEFAULT CHARSET=utf8", 1)
 	}
 }
 
@@ -764,7 +745,7 @@ func fixPartitioningEdgeCases(t *Table, flavor Flavor) {
 		strings.Contains(t.CreateStatement, " DATA DIRECTORY = ") {
 		for _, p := range t.Partitioning.Partitions {
 			name := p.Name
-			if flavor.VendorMinVersion(VendorMariaDB, 10, 2) {
+			if flavor.Min(FlavorMariaDB102) {
 				name = EscapeIdentifier(name)
 			}
 			name = regexp.QuoteMeta(name)
@@ -875,7 +856,7 @@ func fixChecks(t *Table, flavor Flavor) {
 	// prevent explicitly-named checks from also having that same name.
 	// MariaDB also truncates the check clause at 64 bytes in I_S, so we must
 	// parse longer checks from SHOW CREATE TABLE.
-	if flavor.Vendor == VendorMariaDB {
+	if flavor.IsMariaDB() {
 		colsByName := t.ColumnsByName()
 		var keep []*Check
 		for _, cc := range t.Checks {
@@ -980,7 +961,7 @@ func querySchemaRoutines(ctx context.Context, db *sqlx.DB, schema string, flavor
 	// If mysql.proc doesn't exist or that query fails, we then run a SHOW CREATE
 	// per routine, using multiple goroutines for performance reasons.
 	var alreadyObtained int
-	if !flavor.HasDataDictionary() {
+	if !flavor.Min(FlavorMySQL80) {
 		var rawRoutineMeta []struct {
 			Name      string `db:"name"`
 			Type      string `db:"type"`
