@@ -3,6 +3,7 @@ package tengo
 import (
 	"fmt"
 	"os"
+	"path/filepath"
 	"strings"
 	"testing"
 )
@@ -55,6 +56,18 @@ func (s *TengoIntegrationSuite) BeforeTest(backend string) error {
 	return err
 }
 
+// SourceTestSQL executes the supplied sql file(s), which should be supplied
+// relative to the testdata subdir. If any errors occur, the test fails.
+func (s *TengoIntegrationSuite) SourceTestSQL(t *testing.T, files ...string) {
+	t.Helper()
+	for _, f := range files {
+		fPath := filepath.Join("testdata", f)
+		if _, err := s.d.SourceSQL(fPath); err != nil {
+			t.Fatal(err.Error())
+		}
+	}
+}
+
 func (s *TengoIntegrationSuite) GetSchema(t *testing.T, schemaName string) *Schema {
 	t.Helper()
 	schema, err := s.d.Schema(schemaName)
@@ -94,9 +107,9 @@ func TestObjectKeyString(t *testing.T) {
 func TestUnitTableFlavors(t *testing.T) {
 	orig := aTable(1)
 
-	table := aTableForFlavor(FlavorPercona57, 1)
+	table := aTableForFlavor(FlavorMySQL57, 1)
 	if clauses, supported := table.Diff(&orig); !supported || len(clauses) != 0 {
-		t.Errorf("Percona 5.7: Expected no diff; instead found %d differences, supported=%t", len(clauses), supported)
+		t.Errorf("MySQL 5.7: Expected no diff; instead found %d differences, supported=%t", len(clauses), supported)
 	}
 	table = aTableForFlavor(FlavorMariaDB101, 1)
 	if clauses, supported := table.Diff(&orig); !supported || len(clauses) != 0 {
@@ -138,6 +151,66 @@ func TestUnitTableFlavors(t *testing.T) {
 	}
 }
 
+// flavorTestFiles returns a slice of .sql filenames that could run for the
+// supplied flavor. The supplied flavor should have a *non-zero* Patch field,
+// as this is especially relevant for MySQL 8.
+// The result omits integration.sql, since that is always run prior to each
+// subtest.
+func flavorTestFiles(flavor Flavor) []string {
+	// Non-flavor-specific
+	result := []string{"integration-ext.sql", "partition.sql", "rows.sql", "views.sql"}
+
+	if flavor.Min(FlavorMySQL80.Dot(13)) {
+		result = append(result, "default-expr.sql")
+	} else if flavor.Min(FlavorMariaDB102) {
+		result = append(result, "default-expr-maria.sql") // No support for 4-byte chars in the expressions
+	}
+
+	if flavor.GeneratedColumns() {
+		if flavor.IsMariaDB() {
+			result = append(result, "generatedcols-maria.sql") // no support for NOT NULL generated cols or 4-byte chars in generation expressions
+		} else {
+			result = append(result, "generatedcols.sql")
+		}
+	}
+
+	if flavor.Min(FlavorMySQL80) {
+		result = append(result, "index-mysql8.sql") // functional indexes, descending indexes, invisible indexes
+	} else if flavor.Min(FlavorMariaDB106) {
+		result = append(result, "index-maria106.sql") // ignored indexes
+	}
+
+	if flavor.Min(FlavorMariaDB103) || flavor.Min(FlavorMySQL80.Dot(23)) {
+		result = append(result, "inviscols.sql")
+	}
+
+	if flavor.Min(FlavorMySQL57) {
+		result = append(result, "ft-parser.sql") // other flavors may support FT parsers but don't ship with any alternatives
+	}
+
+	if flavor.Min(FlavorPercona56.Dot(33)) {
+		result = append(result, "colcompression-percona.sql")
+	} else if flavor.Min(FlavorMariaDB103) {
+		result = append(result, "colcompression-maria.sql")
+	}
+
+	if flavor.Min(FlavorMySQL57) {
+		result = append(result, "pagecompression.sql")
+	} else if flavor.Min(FlavorMariaDB102) {
+		result = append(result, "pagecompression-maria.sql")
+	}
+
+	if flavor.HasCheckConstraints() {
+		if flavor.IsMariaDB() {
+			result = append(result, "check-maria.sql")
+		} else {
+			result = append(result, "check.sql")
+		}
+	}
+
+	return result
+}
+
 func primaryKey(cols ...*Column) *Index {
 	parts := make([]IndexPart, len(cols))
 	for n := range cols {
@@ -161,7 +234,7 @@ func aTable(nextAutoInc uint64) Table {
 func aTableForFlavor(flavor Flavor, nextAutoInc uint64) Table {
 	utf8mb3 := "utf8"
 	utf8mb3DefaultCollation := "utf8_general_ci"
-	if flavor.VendorMinVersion(VendorMariaDB, 10, 6) {
+	if flavor.Min(FlavorMariaDB106) {
 		utf8mb3 = "utf8mb3"
 		utf8mb3DefaultCollation = "utf8mb3_general_ci"
 	}
@@ -172,13 +245,13 @@ func aTableForFlavor(flavor Flavor, nextAutoInc uint64) Table {
 		OnUpdate: "CURRENT_TIMESTAMP(2)",
 	}
 	lastUpdateDef := "`last_update` timestamp(2) NOT NULL DEFAULT CURRENT_TIMESTAMP(2) ON UPDATE CURRENT_TIMESTAMP(2)"
-	if !flavor.FractionalTimestamps() {
+	if flavor.Matches(FlavorMySQL55) { // No fractional timestamps in 5.5
 		lastUpdateCol.TypeInDB = "timestamp"
 		lastUpdateCol.Default = "CURRENT_TIMESTAMP"
 		lastUpdateCol.OnUpdate = "CURRENT_TIMESTAMP"
 		lastUpdateDef = "`last_update` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"
 	}
-	if flavor.VendorMinVersion(VendorMariaDB, 10, 2) {
+	if flavor.Min(FlavorMariaDB102) {
 		lastUpdateCol.Default = strings.ToLower(lastUpdateCol.Default)
 		lastUpdateCol.OnUpdate = strings.ToLower(lastUpdateCol.OnUpdate)
 		lastUpdateDef = strings.Replace(lastUpdateDef, "CURRENT_TIMESTAMP", "current_timestamp", 2)
@@ -190,7 +263,7 @@ func aTableForFlavor(flavor Flavor, nextAutoInc uint64) Table {
 		Default:  "'1'",
 	}
 	aliveDef := "`alive` tinyint(1) unsigned NOT NULL DEFAULT '1'"
-	if flavor.VendorMinVersion(VendorMariaDB, 10, 2) {
+	if flavor.Min(FlavorMariaDB102) {
 		aliveCol.Default = "1"
 		aliveDef = "`alive` tinyint(1) unsigned NOT NULL DEFAULT 1"
 	}
@@ -255,6 +328,14 @@ func aTableForFlavor(flavor Flavor, nextAutoInc uint64) Table {
 	if nextAutoInc > 1 {
 		autoIncClause = fmt.Sprintf(" AUTO_INCREMENT=%d", nextAutoInc)
 	}
+
+	utf8mb3Table := utf8mb3
+	if flavor.Min(FlavorMySQL80.Dot(24)) {
+		// 8.0.24+ changes how utf8mb3 is expressed for table-level default in
+		// SHOW CREATE, but not anywhere else
+		utf8mb3Table = "utf8mb3"
+	}
+
 	stmt := fmt.Sprintf(`CREATE TABLE `+"`"+`actor`+"`"+` (
   `+"`"+`actor_id`+"`"+` smallint(5) unsigned NOT NULL AUTO_INCREMENT,
   `+"`"+`first_name`+"`"+` varchar(45) NOT NULL,
@@ -266,7 +347,7 @@ func aTableForFlavor(flavor Flavor, nextAutoInc uint64) Table {
   PRIMARY KEY (`+"`"+`actor_id`+"`"+`),
   UNIQUE KEY `+"`"+`idx_ssn`+"`"+` (`+"`"+`ssn`+"`"+`),
   KEY `+"`"+`idx_actor_name`+"`"+` (`+"`"+`last_name`+"`"+`(10),`+"`"+`first_name`+"`"+`(1))
-) ENGINE=InnoDB%s DEFAULT CHARSET=%s`, autoIncClause, utf8mb3)
+) ENGINE=InnoDB%s DEFAULT CHARSET=%s`, autoIncClause, utf8mb3Table)
 	table := Table{
 		Name:               "actor",
 		Engine:             "InnoDB",
@@ -401,7 +482,7 @@ func supportedTableForFlavor(flavor Flavor) Table {
   ~metadata~ text,
   PRIMARY KEY (~post_id~,~user_id~)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1`, "~", "`", -1)
-	if flavor.AllowBlobDefaults() {
+	if flavor.Min(FlavorMariaDB102) { // allow explicit DEFAULT NULL for blob/text
 		columns[3].Default = "NULL"
 		stmt = strings.Replace(stmt, " text", " text DEFAULT NULL", 1)
 	}
@@ -521,10 +602,9 @@ func foreignKeyTable() Table {
 
 func stripIntDisplayWidths(table *Table) {
 	for _, col := range table.Columns {
-		if strings.Contains(col.TypeInDB, "int(") || col.TypeInDB == "year(4)" {
-			stripped := StripDisplayWidth(col.TypeInDB)
-			table.CreateStatement = strings.Replace(table.CreateStatement, col.TypeInDB, stripped, 1)
-			col.TypeInDB = stripped
+		if strippedType, didStrip := StripDisplayWidth(col.TypeInDB); didStrip {
+			table.CreateStatement = strings.Replace(table.CreateStatement, col.TypeInDB, strippedType, 1)
+			col.TypeInDB = strippedType
 		}
 	}
 }
@@ -551,7 +631,7 @@ func aProc(dbCollation, sqlMode string) Routine {
   END`,
 		ParamString:       "\n    IN name varchar(30) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin,\n    INOUT iterations int(10) unsigned,   OUT pct decimal(5, 2)\n",
 		ReturnDataType:    "",
-		Definer:           "root@localhost",
+		Definer:           "root@%",
 		DatabaseCollation: dbCollation,
 		Comment:           "",
 		Deterministic:     false,
@@ -570,7 +650,7 @@ func aFunc(dbCollation, sqlMode string) Routine {
 		Body:              "return mult * 2.0",
 		ParamString:       "mult float(10,2)",
 		ReturnDataType:    "float",
-		Definer:           "root@localhost",
+		Definer:           "root@%",
 		DatabaseCollation: dbCollation,
 		Comment:           "hello world",
 		Deterministic:     true,
